# FAQ

Frequently asked questions and answers:

- **What is BlocksNet?**
  _BlocksNet is an open-source library for generating master plan requirements for urban areas._

Sorry, no other questions were asked...
